.. _usage-utilities:


Helper functions and variables
=================================

``utils``
---------------------
The :doc:`generated/utils` subpackage contains utility functions for displaying data
(:mod:`utils.display`) in a certain way, or downloading files from github:
:func:`utils.files.download_from_github`.

